Surface.AST.If (surface v0.4.1) View Source
An AST node representing an if expression
Properties
* `:condition` - a quoted expression
* `:children` - the children to insert into the dom if the condition evaluates truthy
* `:meta` - compilation meta data
* `:debug` - keyword list indicating when debug information should be printed during compilation
Link to this section Summary
Link to this section Types
Specs
t() :: %Surface.AST.If{
children: [Surface.AST.t()],
condition: any(),
debug: [atom()],
meta: Surface.AST.Meta.t()
}