Surface.AST.Slot (surface v0.4.0) View Source
An AST node representing a <slot /> element
Properties
* `:name` - the slot name
* `:index` - the index of the slotable entry assigned to this slot
* `:default` - a list of AST nodes representing the default content for this slot
* `:props` - either an atom or a quoted expression representing bindings for this slot
* `:meta` - compilation meta data
Link to this section Summary
Link to this section Types
Specs
t() :: %Surface.AST.Slot{
default: [Surface.AST.t()],
directives: [Surface.AST.Directive.t()],
index: any(),
meta: Surface.AST.Meta.t(),
name: binary(),
props: [Keyword.t(any())]
}