Surface.Components.Form.Label (surface v0.1.0) View Source
Defines a label.
Provides a wrapper for Phoenix.HTML.Form's label/3 function.
All options passed via opts will be sent to label/3, class can
be set directly and will override anything in opts.
Properties
- form :form - The form identifier.
- field :atom - The field name.
- class :css_class - The CSS class for the underlying tag.
- opts :keyword, default: [] - Options list.
Link to this section Summary
Functions
Callback implementation for Phoenix.LiveComponent.mount/1.
Callback implementation for Phoenix.LiveComponent.render/1.
Link to this section Functions
Callback implementation for Phoenix.LiveComponent.mount/1.
Callback implementation for Phoenix.LiveComponent.render/1.