Surface.Components.Form.Reset (surface v0.1.0) View Source
Defines a reset button.
Provides a wrapper for Phoenix.HTML.Form's reset/2 function.
All options passed via opts will be sent to reset/2, value and
class can be set directly and will override anything in opts.
Examples
<Reset value="Reset" opts={{ autofocus: "autofocus" }}>Properties
- value :string, default: "Reset" - Value to pre-populated the input.
- class :css_class - Class or classes to apply to the input.
- opts :keyword, default: [] - Keyword list with options to be passed down to
reset/2. - blur :event - Triggered when the component loses focus.
- focus :event - Triggered when the component receives focus.
- capture_click :event - Triggered when the component receives click.
- keydown :event - Triggered when a button on the keyboard is pressed.
- keyup :event - Triggered when a button on the keyboard is released.
Link to this section Summary
Functions
Callback implementation for Phoenix.LiveComponent.mount/1.
Callback implementation for Phoenix.LiveComponent.render/1.
Link to this section Functions
Callback implementation for Phoenix.LiveComponent.mount/1.
Callback implementation for Phoenix.LiveComponent.render/1.