Surface.Components.Form.TelephoneInput (surface v0.1.0) View Source
An input field that let the user enter a telephone number.
Provides a wrapper for Phoenix.HTML.Form's telephone_input/3 function.
All options passed via opts will be sent to telephone_input/3, value,
pattern and class can be set directly and will override anything in opts.
Examples
<TelephoneInput form="user" field="phone" opts={{ autofocus: "autofocus" }} />Properties
- form :form - An identifier for the form.
- field :atom - An identifier for the input.
- value :string - Value to pre-populated the input.
- class :css_class - Class or classes to apply to the input.
- opts :keyword, default: [] - Options list.
- blur :event - Triggered when the component loses focus.
- focus :event - Triggered when the component receives focus.
- capture_click :event - Triggered when the component receives click.
- keydown :event - Triggered when a button on the keyboard is pressed.
- keyup :event - Triggered when a button on the keyboard is released.
- pattern :string - A regular expression to validate the entered value.
Link to this section Summary
Functions
Callback implementation for Phoenix.LiveComponent.mount/1.
Callback implementation for Phoenix.LiveComponent.render/1.
Link to this section Functions
Callback implementation for Phoenix.LiveComponent.mount/1.
Callback implementation for Phoenix.LiveComponent.render/1.