Surface.Components.Raw (Surface v0.12.3)

Copy Markdown View Source

A macro component that does not translate any of its contents.

The content will be passed untouched to the underlying Phoenix's template engine.

Note: By skipping translation, all Surface specific features are automatically disabled, including code interpolation with {...}, syntactic sugar for attributes and markup validation.

Slots

  • default - The content that will not be translated by Surface

Summary

Functions

expand(attributes, content, meta)

Callback implementation for Surface.MacroComponent.expand/3.